You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@shiro.apache.org by ad...@apache.org on 2009/06/18 05:13:47 UTC

svn commit: r785881 [4/11] - in /incubator/shiro/trunk: ./ all/ core/src/main/java/org/apache/ki/ core/src/main/java/org/apache/shiro/ core/src/main/java/org/apache/shiro/aop/ core/src/main/java/org/apache/shiro/authc/ core/src/main/java/org/apache/shi...

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/BlowfishCipher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/BlowfishCipher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Hash.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Hash.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.crypto.hash;
+package org.apache.shiro.crypto.hash;
 
 /**
  * A Cryptoraphic <tt>Hash</tt> represents a one-way conversion algorithm that transforms an input source to an underlying

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Md2Hash.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Md2Hash.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Md2Hash.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Md2Hash.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.crypto.hash;
+package org.apache.shiro.crypto.hash;
 
-import org.apache.ki.codec.Base64;
-import org.apache.ki.codec.Hex;
+import org.apache.shiro.codec.Base64;
+import org.apache.shiro.codec.Hex;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Md5Hash.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Md5Hash.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Md5Hash.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Md5Hash.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.crypto.hash;
+package org.apache.shiro.crypto.hash;
 
-import org.apache.ki.codec.Base64;
-import org.apache.ki.codec.Hex;
+import org.apache.shiro.codec.Base64;
+import org.apache.shiro.codec.Hex;
 
 /**
  * Generates an MD5 Hash (RFC 1321) from a given input <tt>source</tt> with an optional <tt>salt</tt> and

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha1Hash.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha1Hash.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha1Hash.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha1Hash.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.crypto.hash;
+package org.apache.shiro.crypto.hash;
 
-import org.apache.ki.codec.Base64;
-import org.apache.ki.codec.Hex;
+import org.apache.shiro.codec.Base64;
+import org.apache.shiro.codec.Hex;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha256Hash.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha256Hash.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha256Hash.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha256Hash.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.crypto.hash;
+package org.apache.shiro.crypto.hash;
 
-import org.apache.ki.codec.Base64;
-import org.apache.ki.codec.Hex;
+import org.apache.shiro.codec.Base64;
+import org.apache.shiro.codec.Hex;
 
 /**
  * Generates an SHA-256 Hash from a given input <tt>source</tt> with an optional <tt>salt</tt> and hash iterations.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha384Hash.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha384Hash.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha384Hash.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha384Hash.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.crypto.hash;
+package org.apache.shiro.crypto.hash;
 
-import org.apache.ki.codec.Base64;
-import org.apache.ki.codec.Hex;
+import org.apache.shiro.codec.Base64;
+import org.apache.shiro.codec.Hex;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha512Hash.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha512Hash.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha512Hash.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Sha512Hash.java Thu Jun 18 03:13:34 2009
@@ -16,10 +16,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.crypto.hash;
+package org.apache.shiro.crypto.hash;
 
-import org.apache.ki.codec.Base64;
-import org.apache.ki.codec.Hex;
+import org.apache.shiro.codec.Base64;
+import org.apache.shiro.codec.Hex;
 
 /**
  * Generates an SHA-512 Hash from a given input <tt>source</tt> with an optional <tt>salt</tt> and hash iterations.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/AbstractResource.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/AbstractResource.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.io;
+package org.apache.shiro.io;
 
 import java.io.IOException;
 import java.io.InputStream;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/DefaultSerializer.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/DefaultSerializer.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/DefaultSerializer.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/DefaultSerializer.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.io;
+package org.apache.shiro.io;
 
 import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/IniResource.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/IniResource.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/IniResource.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/IniResource.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.io;
+package org.apache.shiro.io;
 
 import java.io.InputStream;
 import java.io.Reader;
@@ -28,8 +28,8 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import static org.apache.ki.util.StringUtils.clean;
-import static org.apache.ki.util.StringUtils.splitKeyValue;
+import static org.apache.shiro.util.StringUtils.clean;
+import static org.apache.shiro.util.StringUtils.splitKeyValue;
 
 /**
  * //TODO - complete JavaDoc

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/ResourceException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/ResourceException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/ResourceException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/ResourceException.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.io;
+package org.apache.shiro.io;
 
-import org.apache.ki.KiException;
+import org.apache.shiro.ShiroException;
 
 
 /**
@@ -27,7 +27,8 @@
  * @author Les Hazlewood
  * @since 0.9
  */
-public class ResourceException extends KiException {
+public class ResourceException extends ShiroException
+{
 
     /**
      * Creates a new ResourceException.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/ResourceUtils.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/ResourceUtils.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/ResourceUtils.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/ResourceUtils.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.io;
+package org.apache.shiro.io;
 
 import java.io.FileInputStream;
 import java.io.IOException;
@@ -26,7 +26,7 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.util.ClassUtils;
+import org.apache.shiro.util.ClassUtils;
 
 /**
  * Static helper methods for loading resources.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/SerializationException.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/SerializationException.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/SerializationException.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/SerializationException.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.io;
+package org.apache.shiro.io;
 
-import org.apache.ki.KiException;
+import org.apache.shiro.ShiroException;
 
 
 /**
@@ -27,7 +27,8 @@
  * @author Les Hazlewood
  * @since Apr 23, 2008 8:58:22 AM
  */
-public class SerializationException extends KiException {
+public class SerializationException extends ShiroException
+{
 
     /**
      * Creates a new SerializationException.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/Serializer.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/Serializer.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/TextResource.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/TextResource.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.io;
+package org.apache.shiro.io;
 
 import java.io.BufferedReader;
 import java.io.IOException;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/XmlSerializer.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/XmlSerializer.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/XmlSerializer.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/XmlSerializer.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.io;
+package org.apache.shiro.io;
 
 import java.beans.XMLDecoder;
 import java.beans.XMLEncoder;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/package-info.java Thu Jun 18 03:13:34 2009
@@ -19,4 +19,4 @@
 /**
  * Support for reading and writing (input/output) raw data from multiple resource locations.
  */
-package org.apache.ki.io;
+package org.apache.shiro.io;

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/JndiCallback.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/JndiCallback.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/JndiCallback.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/JndiCallback.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.jndi;
+package org.apache.shiro.jndi;
 
 import javax.naming.Context;
 import javax.naming.NamingException;
@@ -34,7 +34,7 @@
  * <p>Note that this interface is an exact copy of the Spring Framework's identically named interface from
  * their 2.5.4 distribution - we didn't want to re-invent the wheel, but not require a full dependency on the
  * Spring framework, nor does Spring make available only its JNDI classes in a small jar, or we would have used that.
- * Since Ki is also Apache 2.0 licensed, all regular licenses and conditions and authors have remained in tact.
+ * Since Shiro is also Apache 2.0 licensed, all regular licenses and conditions and authors have remained in tact.
  *
  * @author Rod Johnson
  * @see JndiTemplate

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/JndiLocator.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/JndiLocator.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/JndiLocator.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/JndiLocator.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.jndi;
+package org.apache.shiro.jndi;
 
 import java.util.Properties;
 import javax.naming.NamingException;
@@ -31,7 +31,7 @@
  * <p>Note that this implementation is an almost exact combined copy of the Spring Framework's 'JndiAccessor' and
  * 'JndiLocatorSupport' classes from their 2.5.4 distribution - we didn't want to re-invent the wheel, but not require
  * a full dependency on the Spring framework, nor does Spring make available only its JNDI classes in a small jar, or
- * we would have used that. Since Ki is also Apache 2.0 licensed, all regular licenses and conditions and
+ * we would have used that. Since Shiro is also Apache 2.0 licensed, all regular licenses and conditions and
  * authors have remained in tact.
  *
  * @author Juergen Hoeller

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/JndiTemplate.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/JndiTemplate.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/JndiTemplate.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/JndiTemplate.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.jndi;
+package org.apache.shiro.jndi;
 
 import java.util.Enumeration;
 import java.util.Hashtable;
@@ -37,7 +37,7 @@
  * <p>Note that this implementation is an almost exact copy of the Spring Framework's identically named class from
  * their 2.5.4 distribution - we didn't want to re-invent the wheel, but not require a full dependency on the
  * Spring framework, nor does Spring make available only its JNDI classes in a small jar, or we would have used that.
- * Since Ki is also Apache 2.0 licensed, all regular licenses and conditions and authors have remained in tact.
+ * Since Shiro is also Apache 2.0 licensed, all regular licenses and conditions and authors have remained in tact.
  *
  * @author Rod Johnson
  * @author Juergen Hoeller

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/DefaultSubjectFactory.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/DefaultSubjectFactory.java Thu Jun 18 03:13:34 2009
@@ -16,18 +16,18 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
 import java.net.InetAddress;
 
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.InetAuthenticationToken;
-import org.apache.ki.session.Session;
-import org.apache.ki.subject.DelegatingSubject;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.subject.Subject;
-import org.apache.ki.util.ThreadContext;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.InetAuthenticationToken;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.subject.DelegatingSubject;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.util.ThreadContext;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/RealmSecurityManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/RealmSecurityManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/RememberMeManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/RememberMeManager.java Thu Jun 18 03:13:34 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.subject.PrincipalCollection;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.subject.PrincipalCollection;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SecurityManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SecurityManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SecurityManagerFactory.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SecurityManagerFactory.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
 /**
  * Allows implementations to create and return an application's SecurityManager instance in any manner necessary.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SessionSubjectBinder.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SessionSubjectBinder.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SubjectBinder.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SubjectBinder.java Thu Jun 18 03:13:34 2009
@@ -16,9 +16,9 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.subject.Subject;
 
 
 /**

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SubjectFactory.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SubjectFactory.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/ThreadContextSubjectBinder.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/ThreadContextSubjectBinder.java Thu Jun 18 03:13:34 2009
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.subject.Subject;
-import org.apache.ki.util.ThreadContext;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.util.ThreadContext;
 
 /**
  * Associates a {@link Subject Subject} instance to the currently executing thread via the {
@@ -30,7 +30,7 @@
  * @author Les Hazlewood
  * @link ThreadContext ThreadContext} to ensure that the <code>Subject</code> is accessible to any caller during
  * thread execution.
- * @see org.apache.ki.SecurityUtils#getSubject SecurityUtils.getSubject()
+ * @see org.apache.shiro.SecurityUtils#getSubject SecurityUtils.getSubject()
  * @since 1.0
  */
 public class ThreadContextSubjectBinder implements SubjectBinder {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/BlowfishCipher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/BlowfishCipher.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.crypto;
+package org.apache.shiro.crypto;
 
 import java.security.InvalidKeyException;
 import java.security.Key;
@@ -28,20 +28,20 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.codec.Base64;
-import org.apache.ki.codec.CodecSupport;
+import org.apache.shiro.codec.Base64;
+import org.apache.shiro.codec.CodecSupport;
 
 
 /**
  * Ki's default symmetric block Cipher using the Blowfish algorithm.  As it is a symmetric Cipher, it uses the
  * same <tt>Key</tt> to both encrypt and decrypt data.  If one is not provided via the {@link #setKey setKey} method,
  * a default one will be used, BUT NOTE:
  *
  * <p>Because Ki is an open-source project, if anyone knew that you were using Ki's default
  * <code>Key</code>, they could download/view the source, and with enough effort, reconstruct the <code>Key</code>
  * and decode encrypted data at will.
  *
  * <p>Ki only really uses Ciphers to encrypt user ids and session ids, so if that information is not critical
  * to you and you think the default key still makes things 'sufficiently difficult', then you can ignore this issue.
  *
  * <p>However, if you do feel this constitutes sensitive information, it is recommended that you provide your own
@@ -70,7 +70,7 @@
     //The following KEY_BYTES String was created by running
     //System.out.println( Base64.encode( generateNewKey().getEncoded() ) ); and copying-n-pasting the output here.
     //You should run the same and set the resulting output as a property of this class instead of using
     //Ki's default Key for proper security.
     private static final byte[] KEY_BYTES = Base64.decode("jJ9Kg1BAevbvhSg3vBfwfQ==");
     private static final Key DEFAULT_CIPHER_KEY = new SecretKeySpec(KEY_BYTES, ALGORITHM);
 
@@ -28,20 +28,20 @@
 
 /**
- * Ki's default symmetric block Cipher using the Blowfish algorithm.  As it is a symmetric Cipher, it uses the
+ * Shiro's default symmetric block Cipher using the Blowfish algorithm.  As it is a symmetric Cipher, it uses the
  * same <tt>Key</tt> to both encrypt and decrypt data.  If one is not provided via the {@link #setKey setKey} method,
  * a default one will be used, BUT NOTE:
@@ -28,20 +28,20 @@
  * a default one will be used, BUT NOTE:
  *
- * <p>Because Ki is an open-source project, if anyone knew that you were using Ki's default
+ * <p>Because Shiro is an open-source project, if anyone knew that you were using Shiro's default
  * <code>Key</code>, they could download/view the source, and with enough effort, reconstruct the <code>Key</code>
  * and decode encrypted data at will.
@@ -28,20 +28,20 @@
  * and decode encrypted data at will.
  *
- * <p>Ki only really uses Ciphers to encrypt user ids and session ids, so if that information is not critical
+ * <p>Shiro only really uses Ciphers to encrypt user ids and session ids, so if that information is not critical
  * to you and you think the default key still makes things 'sufficiently difficult', then you can ignore this issue.
  *
@@ -70,7 +70,7 @@
     //System.out.println( Base64.encode( generateNewKey().getEncoded() ) ); and copying-n-pasting the output here.
     //You should run the same and set the resulting output as a property of this class instead of using
-    //Ki's default Key for proper security.
+    //Shiro's default Key for proper security.
     private static final byte[] KEY_BYTES = Base64.decode("jJ9Kg1BAevbvhSg3vBfwfQ==");
     private static final Key DEFAULT_CIPHER_KEY = new SecretKeySpec(KEY_BYTES, ALGORITHM);

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/Cipher.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/Cipher.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/Cipher.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/Cipher.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.crypto;
+package org.apache.shiro.crypto;
 
 /**
  * A <tt>Cipher</tt> is an algorithm used in cryptography that converts an original input source using a <tt>Key</tt> to
@@ -40,9 +40,9 @@
  * data shared between two parties, the same Key must also be shared and may be compromised.
  *
  * <p>Note that a symmetric cipher is perfectly fine to use if you just want to encode data in a format no one else
  * can understand and you never give away the key.  Ki uses a symmetric cipher when using certain
  * HTTP Cookies for example - because it is often undesireable to have user's identity stored in a plain-text cookie,
  * that identity can be converted via a symmetric cipher.  Since the the same exact Ki application will receive
  * the cookie, it can decrypt it via the same <tt>Key</tt> and there is no potential for discovery since that Key
  * is never shared with anyone.
  *
@@ -40,9 +40,9 @@
  *
  * <p>Note that a symmetric cipher is perfectly fine to use if you just want to encode data in a format no one else
- * can understand and you never give away the key.  Ki uses a symmetric cipher when using certain
+ * can understand and you never give away the key.  Shiro uses a symmetric cipher when using certain
  * HTTP Cookies for example - because it is often undesireable to have user's identity stored in a plain-text cookie,
@@ -40,9 +40,9 @@
  * HTTP Cookies for example - because it is often undesireable to have user's identity stored in a plain-text cookie,
- * that identity can be converted via a symmetric cipher.  Since the the same exact Ki application will receive
+ * that identity can be converted via a symmetric cipher.  Since the the same exact Shiro application will receive
  * the cookie, it can decrypt it via the same <tt>Key</tt> and there is no potential for discovery since that Key
  * is never shared with anyone.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/AbstractHash.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/AbstractHash.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/AbstractHash.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/AbstractHash.java Thu Jun 18 03:13:34 2009
@@ -16,20 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.crypto.hash;
+package org.apache.shiro.crypto.hash;
 
 import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
 import java.util.Arrays;
 import java.io.Serializable;
 
-import org.apache.ki.codec.Base64;
-import org.apache.ki.codec.CodecException;
-import org.apache.ki.codec.CodecSupport;
-import org.apache.ki.codec.Hex;
+import org.apache.shiro.codec.Base64;
+import org.apache.shiro.codec.CodecException;
+import org.apache.shiro.codec.CodecSupport;
+import org.apache.shiro.codec.Hex;
 
 /**
  * Provides a base for all Ki Hash algorithms with support for salts and multiple hash iterations.
  *
  * <p>Read <a href="http://www.owasp.org/index.php/Hashing_Java" target="blank">http://www.owasp.org/index.php/Hashing_Java</a> for a
  * good article on the benefits of hashing, including what a 'salt' is as well as why it and multiple hash iterations
@@ -104,7 +104,7 @@
      *
      * <p>By default, this class only supports Object method arguments of
      * type <tt>byte[]</tt>, <tt>char[]</tt> and <tt>String</tt>.  If either argument is anything other than these
      * types a {@link org.apache.ki.codec.CodecException CodecException} will be thrown.
      *
      * <p>If you want to be able to hash other object types, or use other salt types, you need to override the
      * {@link #toBytes(Object) toBytes(Object)} method to support those specific types.  Your other option is to
@@ -16,20 +16,20 @@
 
 /**
- * Provides a base for all Ki Hash algorithms with support for salts and multiple hash iterations.
+ * Provides a base for all Shiro Hash algorithms with support for salts and multiple hash iterations.
  *
  * <p>Read <a href="http://www.owasp.org/index.php/Hashing_Java" target="blank">http://www.owasp.org/index.php/Hashing_Java</a> for a
@@ -104,7 +104,7 @@
      * <p>By default, this class only supports Object method arguments of
      * type <tt>byte[]</tt>, <tt>char[]</tt> and <tt>String</tt>.  If either argument is anything other than these
-     * types a {@link org.apache.ki.codec.CodecException CodecException} will be thrown.
+     * types a {@link org.apache.shiro.codec.CodecException CodecException} will be thrown.
      *
      * <p>If you want to be able to hash other object types, or use other salt types, you need to override the

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Hash.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/Hash.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/hash/package-info.java Thu Jun 18 03:13:34 2009
@@ -19,7 +19,7 @@
 /**
  * Cryptographic Hashing components that greatly simplify one-way data hashing in an application.
  * <p/>
  * The {@link org.apache.ki.crypto.hash.Hash Hash} interface and its implementations are significantly
  * easier to understand and use compared to the JDK's <code>MessageDigest</code> mechanism.
  */
-package org.apache.ki.crypto.hash;
+package org.apache.shiro.crypto.hash;
@@ -19,7 +19,7 @@
  * Cryptographic Hashing components that greatly simplify one-way data hashing in an application.
  * <p/>
- * The {@link org.apache.ki.crypto.hash.Hash Hash} interface and its implementations are significantly
+ * The {@link org.apache.shiro.crypto.hash.Hash Hash} interface and its implementations are significantly
  * easier to understand and use compared to the JDK's <code>MessageDigest</code> mechanism.
  */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/crypto/package-info.java Thu Jun 18 03:13:34 2009
@@ -20,7 +20,7 @@
  * Cryptography Cipher and Hashing components that greatly simplify the JDK's cryptography concepts and
  * add additional convenient behavior.
  * <p/>
  * The most important interface in this package is the {@link org.apache.ki.crypto.Cipher Cipher} interface, which
  * allows other Ki components to encrypt and decrypt potentially sensitive data.
  */
-package org.apache.ki.crypto;
+package org.apache.shiro.crypto;
@@ -20,7 +20,7 @@
  * add additional convenient behavior.
  * <p/>
- * The most important interface in this package is the {@link org.apache.ki.crypto.Cipher Cipher} interface, which
- * allows other Ki components to encrypt and decrypt potentially sensitive data.
+ * The most important interface in this package is the {@link org.apache.shiro.crypto.Cipher Cipher} interface, which
+ * allows other Shiro components to encrypt and decrypt potentially sensitive data.
  */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/AbstractResource.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/AbstractResource.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/Serializer.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/Serializer.java Thu Jun 18 03:13:34 2009
@@ -16,15 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.io;
+package org.apache.shiro.io;
 
 /**
  * A <code>Serializer</code> converts objects to raw binary data and vice versa, enabling persistent storage
  * of objects to files, HTTP cookies, or other mechanism.
  * <p/>
  * A <code>Serializer</code> should only do conversion, never change the data, such as encoding/decoding or
  * encryption.  These orthoganal concerns are handled elsewhere by Ki, for example, via
  * {@link org.apache.ki.codec.CodecSupport CodecSupport} and {@link org.apache.ki.crypto.Cipher Cipher}s.
  * @author Les Hazlewood
  * @since 0.9
  */
@@ -16,15 +16,15 @@
  * <p/>
  * A <code>Serializer</code> should only do conversion, never change the data, such as encoding/decoding or
- * encryption.  These orthoganal concerns are handled elsewhere by Ki, for example, via
- * {@link org.apache.ki.codec.CodecSupport CodecSupport} and {@link org.apache.ki.crypto.Cipher Cipher}s.
+ * encryption.  These orthoganal concerns are handled elsewhere by Shiro, for example, via
+ * {@link org.apache.shiro.codec.CodecSupport CodecSupport} and {@link org.apache.shiro.crypto.Cipher Cipher}s.
  * @author Les Hazlewood
  * @since 0.9

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/TextResource.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/io/TextResource.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/jndi/package-info.java Thu Jun 18 03:13:34 2009
@@ -17,6 +17,6 @@
  * under the License.
  */
 /**
  * Enables accessing objects located in JNDI that might be useful when configuring a Ki-enabled application.
  */
-package org.apache.ki.jndi;
+package org.apache.shiro.jndi;
@@ -17,6 +17,6 @@
  */
 /**
- * Enables accessing objects located in JNDI that might be useful when configuring a Ki-enabled application.
+ * Enables accessing objects located in JNDI that might be useful when configuring a Shiro-enabled application.
  */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/AbstractRememberMeManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/AbstractRememberMeManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/AbstractRememberMeManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/AbstractRememberMeManager.java Thu Jun 18 03:13:34 2009
@@ -16,29 +16,29 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.RememberMeAuthenticationToken;
-import org.apache.ki.codec.Base64;
-import org.apache.ki.codec.Hex;
-import org.apache.ki.crypto.BlowfishCipher;
-import org.apache.ki.crypto.Cipher;
-import org.apache.ki.io.DefaultSerializer;
-import org.apache.ki.io.SerializationException;
-import org.apache.ki.io.Serializer;
-import org.apache.ki.subject.PrincipalCollection;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.RememberMeAuthenticationToken;
+import org.apache.shiro.codec.Base64;
+import org.apache.shiro.codec.Hex;
+import org.apache.shiro.crypto.BlowfishCipher;
+import org.apache.shiro.crypto.Cipher;
+import org.apache.shiro.io.DefaultSerializer;
+import org.apache.shiro.io.SerializationException;
+import org.apache.shiro.io.Serializer;
+import org.apache.shiro.subject.PrincipalCollection;
 
 
 /**
  * Abstract implementation of the <code>RememberMeManager</code> interface that handles
  * {@link #setSerializer(org.apache.ki.io.Serializer) serialization} and
  * {@link #setCipher(org.apache.ki.crypto.Cipher) encryption} of the remembered user identity.
  * <p/>
  * The remembered identity storage location is implementation-specific.
  *
@@ -16,29 +16,29 @@
 /**
  * Abstract implementation of the <code>RememberMeManager</code> interface that handles
- * {@link #setSerializer(org.apache.ki.io.Serializer) serialization} and
- * {@link #setCipher(org.apache.ki.crypto.Cipher) encryption} of the remembered user identity.
+ * {@link #setSerializer(org.apache.shiro.io.Serializer) serialization} and
+ * {@link #setCipher(org.apache.shiro.crypto.Cipher) encryption} of the remembered user identity.
  * <p/>
  * The remembered identity storage location is implementation-specific.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/AuthenticatingSecurityManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/AuthenticatingSecurityManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/AuthenticatingSecurityManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/AuthenticatingSecurityManager.java Thu Jun 18 03:13:34 2009
@@ -16,23 +16,23 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
 import java.util.Collection;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationListener;
-import org.apache.ki.authc.AuthenticationListenerRegistrar;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.Authenticator;
-import org.apache.ki.authc.pam.AuthenticationStrategy;
-import org.apache.ki.authc.pam.ModularRealmAuthenticator;
-import org.apache.ki.util.LifecycleUtils;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationListener;
+import org.apache.shiro.authc.AuthenticationListenerRegistrar;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.Authenticator;
+import org.apache.shiro.authc.pam.AuthenticationStrategy;
+import org.apache.shiro.authc.pam.ModularRealmAuthenticator;
+import org.apache.shiro.util.LifecycleUtils;
 
 
 /**
  * Ki support of a {@link SecurityManager} class hierarchy that delegates all
  * authentication operations to a wrapped {@link Authenticator Authenticator} instance.  That is, this class
  * implements all the <tt>Authenticator</tt> methods in the {@link SecurityManager SecurityManager}
  * interface, but in reality, those methods are merely passthrough calls to the underlying 'real'
@@ -40,7 +40,7 @@
  *
  * <p>All other <tt>SecurityManager</tt> (authorization, session, etc) methods are left to be implemented by subclasses.
  *
  * <p>In keeping with the other classes in this hierarchy and Ki's desire to minimize configuration whenever
  * possible, suitable default instances for all dependencies are created upon instantiation.
  *
  * @author Les Hazlewood
@@ -57,7 +57,7 @@
     /**
      * Default no-arg constructor that initializes its internal
      * <code>authenticator</code> instance to a
-     * {@link org.apache.ki.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator}.
+     * {@link org.apache.shiro.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator}.
      */
     public AuthenticatingSecurityManager() {
         super();
@@ -67,8 +67,8 @@
     /**
      * Returns the delegate <code>Authenticator</code> instance that this SecurityManager uses to perform all
      * authentication operations.  Unless overridden by the
      * {@link #setAuthenticator(org.apache.ki.authc.Authenticator) setAuthenticator}, the default instance is a
      * {@link org.apache.ki.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator}.
      *
      * @return the delegate <code>Authenticator</code> instance that this SecurityManager uses to perform all
      *         authentication operations.
@@ -80,7 +80,7 @@
     /**
      * Sets the delegate <code>Authenticator</code> instance that this SecurityManager uses to perform all
      * authentication operations.  Unless overridden by this method, the default instance is a
-     * {@link org.apache.ki.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator}.
+     * {@link org.apache.shiro.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator}.
      *
      * @param authenticator the delegate <code>Authenticator</code> instance that this SecurityManager will use to
      *                      perform all authentication operations.
@@ -95,7 +95,7 @@
     }
 
     /**
      * Sets the {@link org.apache.ki.authc.pam.AuthenticationStrategy} to use
      * in multi-realm environments.
      *
      * @param strategy the <code>AuthenticationStrategy</code> to use in multi-realm environments.
@@ -121,11 +121,11 @@
      * and then apply these <tt>AuthenticationListener</tt>s on your behalf.
      *
      * <p>One notice however: The underlying Authenticator delegate must implement the
-     * {@link org.apache.ki.authc.AuthenticationListenerRegistrar AuthenticationListenerRegistrar}
+     * {@link org.apache.shiro.authc.AuthenticationListenerRegistrar AuthenticationListenerRegistrar}
      * interface in order for these listeners to be applied.  If it does not implement this interface, it is
      * considered a configuration error and an exception will be thrown.
      *
      * <p>All of Ki's <tt>Authenticator</tt> implementations implement the
      * <tt>AuthenticationListenerRegistrar</tt> interface, so you would only need
      * to worry about an exception being thrown if you provided your own Authenticator instance and did not
      * implement it.
@@ -157,7 +157,7 @@
 
     /**
      * Ensures that <code>this.authenticator</code> implements the
      * {@link org.apache.ki.authc.AuthenticationListenerRegistrar AuthenticationListenerRegistrar} interface to ensure
      * listeners can be registered.
      */
     private void assertAuthenticatorListenerSupport() {
@@ -182,7 +182,7 @@
     }
 
     /**
      * Delegates to the wrapped {@link org.apache.ki.authc.Authenticator Authenticator} for authentication.
      */
     public AuthenticationInfo authenticate(AuthenticationToken token) throws AuthenticationException {
         return this.authenticator.authenticate(token);
@@ -16,23 +16,23 @@
 
 /**
- * Ki support of a {@link SecurityManager} class hierarchy that delegates all
+ * Shiro support of a {@link SecurityManager} class hierarchy that delegates all
  * authentication operations to a wrapped {@link Authenticator Authenticator} instance.  That is, this class
  * implements all the <tt>Authenticator</tt> methods in the {@link SecurityManager SecurityManager}
@@ -40,7 +40,7 @@
  * <p>All other <tt>SecurityManager</tt> (authorization, session, etc) methods are left to be implemented by subclasses.
  *
- * <p>In keeping with the other classes in this hierarchy and Ki's desire to minimize configuration whenever
+ * <p>In keeping with the other classes in this hierarchy and Shiro's desire to minimize configuration whenever
  * possible, suitable default instances for all dependencies are created upon instantiation.
  *
@@ -67,8 +67,8 @@
      * Returns the delegate <code>Authenticator</code> instance that this SecurityManager uses to perform all
      * authentication operations.  Unless overridden by the
-     * {@link #setAuthenticator(org.apache.ki.authc.Authenticator) setAuthenticator}, the default instance is a
-     * {@link org.apache.ki.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator}.
+     * {@link #setAuthenticator(org.apache.shiro.authc.Authenticator) setAuthenticator}, the default instance is a
+     * {@link org.apache.shiro.authc.pam.ModularRealmAuthenticator ModularRealmAuthenticator}.
      *
      * @return the delegate <code>Authenticator</code> instance that this SecurityManager uses to perform all
@@ -95,7 +95,7 @@
 
     /**
-     * Sets the {@link org.apache.ki.authc.pam.AuthenticationStrategy} to use
+     * Sets the {@link org.apache.shiro.authc.pam.AuthenticationStrategy} to use
      * in multi-realm environments.
      *
@@ -121,11 +121,11 @@
      * considered a configuration error and an exception will be thrown.
      *
-     * <p>All of Ki's <tt>Authenticator</tt> implementations implement the
+     * <p>All of Shiro's <tt>Authenticator</tt> implementations implement the
      * <tt>AuthenticationListenerRegistrar</tt> interface, so you would only need
      * to worry about an exception being thrown if you provided your own Authenticator instance and did not
@@ -157,7 +157,7 @@
     /**
      * Ensures that <code>this.authenticator</code> implements the
-     * {@link org.apache.ki.authc.AuthenticationListenerRegistrar AuthenticationListenerRegistrar} interface to ensure
+     * {@link org.apache.shiro.authc.AuthenticationListenerRegistrar AuthenticationListenerRegistrar} interface to ensure
      * listeners can be registered.
      */
@@ -182,7 +182,7 @@
 
     /**
-     * Delegates to the wrapped {@link org.apache.ki.authc.Authenticator Authenticator} for authentication.
+     * Delegates to the wrapped {@link org.apache.shiro.authc.Authenticator Authenticator} for authentication.
      */
     public AuthenticationInfo authenticate(AuthenticationToken token) throws AuthenticationException {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/AuthorizingSecurityManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/AuthorizingSecurityManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/AuthorizingSecurityManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/AuthorizingSecurityManager.java Thu Jun 18 03:13:34 2009
@@ -16,23 +16,23 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
 import java.util.Collection;
 import java.util.List;
 
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.authz.Authorizer;
-import org.apache.ki.authz.ModularRealmAuthorizer;
-import org.apache.ki.authz.Permission;
-import org.apache.ki.authz.permission.PermissionResolver;
-import org.apache.ki.authz.permission.PermissionResolverAware;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.util.LifecycleUtils;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.authz.Authorizer;
+import org.apache.shiro.authz.ModularRealmAuthorizer;
+import org.apache.shiro.authz.Permission;
+import org.apache.shiro.authz.permission.PermissionResolver;
+import org.apache.shiro.authz.permission.PermissionResolverAware;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.util.LifecycleUtils;
 
 
 /**
  * Ki support of a {@link SecurityManager} class hierarchy that delegates all
  * authorization (access control) operations to a wrapped {@link Authorizer Authorizer} instance.  That is,
  * this class implements all the <tt>Authorizer</tt> methods in the {@link SecurityManager SecurityManager}
  * interface, but in reality, those methods are merely passthrough calls to the underlying 'real'
@@ -41,7 +41,7 @@
  * <p>All remaining <tt>SecurityManager</tt> methods not covered by this class or its parents (mostly Session support)
  * are left to be implemented by subclasses.
  *
  * <p>In keeping with the other classes in this hierarchy and Ki's desire to minimize configuration whenever
  * possible, suitable default instances for all dependencies will be created upon instantiation.
  *
  * @author Les Hazlewood
@@ -56,7 +56,7 @@
 
     /**
      * Default no-arg constructor that initializes an internal default
-     * {@link org.apache.ki.authz.ModularRealmAuthorizer ModularRealmAuthorizer}.
+     * {@link org.apache.shiro.authz.ModularRealmAuthorizer ModularRealmAuthorizer}.
      */
     public AuthorizingSecurityManager() {
         super();
@@ -119,7 +119,7 @@
      * instance's wrapped {@link Authorizer Authorizer}.
      * <p/>
      * The setting of realms the Authorizer will only occur if it is an instance of
      * {@link org.apache.ki.authz.ModularRealmAuthorizer ModularRealmAuthorizer}, that is:
      * <pre>
      * if ( this.authorizer instanceof ModularRealmAuthorizer ) {
      *     ((ModularRealmAuthorizer)this.authorizer).setRealms(realms);
@@ -16,23 +16,23 @@
 
 /**
- * Ki support of a {@link SecurityManager} class hierarchy that delegates all
+ * Shiro support of a {@link SecurityManager} class hierarchy that delegates all
  * authorization (access control) operations to a wrapped {@link Authorizer Authorizer} instance.  That is,
  * this class implements all the <tt>Authorizer</tt> methods in the {@link SecurityManager SecurityManager}
@@ -41,7 +41,7 @@
  * are left to be implemented by subclasses.
  *
- * <p>In keeping with the other classes in this hierarchy and Ki's desire to minimize configuration whenever
+ * <p>In keeping with the other classes in this hierarchy and Shiro's desire to minimize configuration whenever
  * possible, suitable default instances for all dependencies will be created upon instantiation.
  *
@@ -119,7 +119,7 @@
      * <p/>
      * The setting of realms the Authorizer will only occur if it is an instance of
-     * {@link org.apache.ki.authz.ModularRealmAuthorizer ModularRealmAuthorizer}, that is:
+     * {@link org.apache.shiro.authz.ModularRealmAuthorizer ModularRealmAuthorizer}, that is:
      * <pre>
      * if ( this.authorizer instanceof ModularRealmAuthorizer ) {

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/CachingSecurityManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/CachingSecurityManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/CachingSecurityManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/CachingSecurityManager.java Thu Jun 18 03:13:34 2009
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
-import org.apache.ki.cache.CacheManager;
-import org.apache.ki.cache.CacheManagerAware;
-import org.apache.ki.cache.DefaultCacheManager;
-import org.apache.ki.util.Destroyable;
-import org.apache.ki.util.LifecycleUtils;
+import org.apache.shiro.cache.CacheManager;
+import org.apache.shiro.cache.CacheManagerAware;
+import org.apache.shiro.cache.DefaultCacheManager;
+import org.apache.shiro.util.Destroyable;
+import org.apache.shiro.util.LifecycleUtils;
 
 
 /**
@@ -78,7 +78,7 @@
 
     /**
      * Template callback to notify subclasses that a
      * {@link org.apache.ki.cache.CacheManager CacheManager} has been set and is available for use via the
      * {@link #getCacheManager getCacheManager()} method.
      */
     protected void afterCacheManagerSet() {
@@ -78,7 +78,7 @@
     /**
      * Template callback to notify subclasses that a
-     * {@link org.apache.ki.cache.CacheManager CacheManager} has been set and is available for use via the
+     * {@link org.apache.shiro.cache.CacheManager CacheManager} has been set and is available for use via the
      * {@link #getCacheManager getCacheManager()} method.
      */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/DefaultSecurityManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/DefaultSecurityManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/DefaultSecurityManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/DefaultSecurityManager.java Thu Jun 18 03:13:34 2009
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
 import java.io.Serializable;
 import java.net.InetAddress;
@@ -25,28 +25,28 @@
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.Authenticator;
-import org.apache.ki.authc.LogoutAware;
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.authz.Authorizer;
-import org.apache.ki.crypto.Cipher;
-import org.apache.ki.realm.Realm;
-import org.apache.ki.session.InvalidSessionException;
-import org.apache.ki.session.Session;
-import org.apache.ki.session.mgt.DelegatingSession;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.subject.Subject;
-import org.apache.ki.util.ThreadContext;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.Authenticator;
+import org.apache.shiro.authc.LogoutAware;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.authz.Authorizer;
+import org.apache.shiro.crypto.Cipher;
+import org.apache.shiro.realm.Realm;
+import org.apache.shiro.session.InvalidSessionException;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.session.mgt.DelegatingSession;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.subject.Subject;
+import org.apache.shiro.util.ThreadContext;
 
 
 /**
  * <p>The Ki framework's default concrete implementation of the {@link SecurityManager} interface,
  * based around a collection of {@link org.apache.ki.realm.Realm}s.  This implementation delegates its
  * authentication, authorization, and session operations to wrapped {@link Authenticator}, {@link Authorizer}, and
  * {@link org.apache.ki.session.mgt.SessionManager SessionManager} instances respectively via superclass
  * implementation.</p>
  *
  * <p>To greatly reduce and simplify configuration, this implementation (and its superclasses) will
@@ -67,12 +67,12 @@
  * instance yourself via the {@link #setRememberMeManager(RememberMeManager) setRememberMeManager}
  * mutator.  However if you're reading this JavaDoc with the
  * expectation of operating in a Web environment, take a look at the
  * {@link org.apache.ki.web.DefaultWebSecurityManager DefaultWebSecurityManager} implementation, which
  * <em>does</em> support <tt>RememberMe</tt> services by default at startup.
  *
  * @author Les Hazlewood
  * @author Jeremy Haile
- * @see org.apache.ki.web.DefaultWebSecurityManager
+ * @see org.apache.shiro.web.DefaultWebSecurityManager
  * @since 0.2
  */
 public class DefaultSecurityManager extends SessionsSecurityManager {
@@ -479,17 +479,17 @@
      *
      * @param sessionId the id of the session that backs the desired Subject being acquired.
      * @return the {@code Subject} that owns the {@code Session Session} with the specified {@code sessionId}
-     * @throws org.apache.ki.session.InvalidSessionException
+     * @throws org.apache.shiro.session.InvalidSessionException
      *          if the session identified by <tt>sessionId</tt> has
      *          been stopped, expired, or doesn't exist.
-     * @throws org.apache.ki.authz.AuthorizationException
+     * @throws org.apache.shiro.authz.AuthorizationException
      *          if the executor of this method is not allowed to acquire the owning {@code Subject}.  The reason
      *          for the exception is implementation-specific and could be for any number of reasons.  A common
      *          reason in many systems would be if one host tried to acquire a {@code Subject} based on a
      *          {@code Session} that originated on an entirely different host (although it is not a Ki
      *          requirement this scenario is disallowed - its just an example that <em>may</em> throw an Exception in
      *          some systems).
-     * @see org.apache.ki.authz.HostUnauthorizedException
+     * @see org.apache.shiro.authz.HostUnauthorizedException
      * @since 1.0
      */
     private Subject getSubjectBySessionId(Serializable sessionId) throws InvalidSessionException, AuthorizationException {
@@ -25,28 +25,28 @@
 
 /**
- * <p>The Ki framework's default concrete implementation of the {@link SecurityManager} interface,
- * based around a collection of {@link org.apache.ki.realm.Realm}s.  This implementation delegates its
+ * <p>The Shiro framework's default concrete implementation of the {@link SecurityManager} interface,
+ * based around a collection of {@link org.apache.shiro.realm.Realm}s.  This implementation delegates its
  * authentication, authorization, and session operations to wrapped {@link Authenticator}, {@link Authorizer}, and
@@ -25,28 +25,28 @@
  * authentication, authorization, and session operations to wrapped {@link Authenticator}, {@link Authorizer}, and
- * {@link org.apache.ki.session.mgt.SessionManager SessionManager} instances respectively via superclass
+ * {@link org.apache.shiro.session.mgt.SessionManager SessionManager} instances respectively via superclass
  * implementation.</p>
  *
@@ -67,12 +67,12 @@
  * mutator.  However if you're reading this JavaDoc with the
  * expectation of operating in a Web environment, take a look at the
- * {@link org.apache.ki.web.DefaultWebSecurityManager DefaultWebSecurityManager} implementation, which
+ * {@link org.apache.shiro.web.DefaultWebSecurityManager DefaultWebSecurityManager} implementation, which
  * <em>does</em> support <tt>RememberMe</tt> services by default at startup.
  *
@@ -479,17 +479,17 @@
      *          for the exception is implementation-specific and could be for any number of reasons.  A common
      *          reason in many systems would be if one host tried to acquire a {@code Subject} based on a
-     *          {@code Session} that originated on an entirely different host (although it is not a Ki
+     *          {@code Session} that originated on an entirely different host (although it is not a Shiro
      *          requirement this scenario is disallowed - its just an example that <em>may</em> throw an Exception in
      *          some systems).

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/DefaultSubjectFactory.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/DefaultSubjectFactory.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/RealmSecurityManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/RealmSecurityManager.java Thu Jun 18 03:13:34 2009
@@ -16,20 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
 import java.util.ArrayList;
 import java.util.Collection;
 
-import org.apache.ki.cache.CacheManager;
-import org.apache.ki.cache.CacheManagerAware;
-import org.apache.ki.realm.Realm;
-import org.apache.ki.util.LifecycleUtils;
+import org.apache.shiro.cache.CacheManager;
+import org.apache.shiro.cache.CacheManagerAware;
+import org.apache.shiro.realm.Realm;
+import org.apache.shiro.util.LifecycleUtils;
 
 
 /**
  * Ki support of a {@link SecurityManager} class hierarchy based around a collection of
  * {@link org.apache.ki.realm.Realm}s.  All actual {@code SecurityManager} method implementations are left to
  * subclasses.
  *
  * @author Les Hazlewood
@@ -97,10 +97,10 @@
 
     /**
      * Sets the internal {@link #getCacheManager CacheManager} on any internal configured
      * {@link #getRealms Realms} that implement the {@link org.apache.ki.cache.CacheManagerAware CacheManagerAware} interface.
      * <p/>
      * This method is called after setting a cacheManager on this securityManager via the
      * {@link #setCacheManager(org.apache.ki.cache.CacheManager) setCacheManager} method to allow it to be propagated
      * down to all the internal Realms that would need to use it.
      * <p/>
      * It is also called after setting one or more realms via the {@link #setRealm setRealm} or
@@ -121,7 +121,7 @@
 
     /**
      * Simply calls {@link #applyCacheManagerToRealms() applyCacheManagerToRealms()} to allow the
      * newly set {@link org.apache.ki.cache.CacheManager CacheManager} to be propagated to the internal collection of <code>Realm</code>
      * that would need to use it.
      */
     protected void afterCacheManagerSet() {
@@ -16,20 +16,20 @@
 
 /**
- * Ki support of a {@link SecurityManager} class hierarchy based around a collection of
- * {@link org.apache.ki.realm.Realm}s.  All actual {@code SecurityManager} method implementations are left to
+ * Shiro support of a {@link SecurityManager} class hierarchy based around a collection of
+ * {@link org.apache.shiro.realm.Realm}s.  All actual {@code SecurityManager} method implementations are left to
  * subclasses.
  *
@@ -97,10 +97,10 @@
     /**
      * Sets the internal {@link #getCacheManager CacheManager} on any internal configured
-     * {@link #getRealms Realms} that implement the {@link org.apache.ki.cache.CacheManagerAware CacheManagerAware} interface.
+     * {@link #getRealms Realms} that implement the {@link org.apache.shiro.cache.CacheManagerAware CacheManagerAware} interface.
      * <p/>
      * This method is called after setting a cacheManager on this securityManager via the
@@ -97,10 +97,10 @@
      * <p/>
      * This method is called after setting a cacheManager on this securityManager via the
-     * {@link #setCacheManager(org.apache.ki.cache.CacheManager) setCacheManager} method to allow it to be propagated
+     * {@link #setCacheManager(org.apache.shiro.cache.CacheManager) setCacheManager} method to allow it to be propagated
      * down to all the internal Realms that would need to use it.
      * <p/>
@@ -121,7 +121,7 @@
     /**
      * Simply calls {@link #applyCacheManagerToRealms() applyCacheManagerToRealms()} to allow the
-     * newly set {@link org.apache.ki.cache.CacheManager CacheManager} to be propagated to the internal collection of <code>Realm</code>
+     * newly set {@link org.apache.shiro.cache.CacheManager CacheManager} to be propagated to the internal collection of <code>Realm</code>
      * that would need to use it.
      */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/RememberMeManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/RememberMeManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SecurityManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SecurityManager.java Thu Jun 18 03:13:34 2009
@@ -16,30 +16,30 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
-import org.apache.ki.authc.AuthenticationException;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.authc.Authenticator;
-import org.apache.ki.authz.Authorizer;
-import org.apache.ki.session.mgt.SessionManager;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.authc.Authenticator;
+import org.apache.shiro.authz.Authorizer;
+import org.apache.shiro.session.mgt.SessionManager;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.subject.Subject;
 
 
 /**
  * A <tt>SecurityManager</tt> executes all security operations for <em>all</em> Subjects (aka users) across a
  * single application.
  * <p/>
  * The interface itself primarily exists as a convenience - it extends the {@link org.apache.ki.authc.Authenticator},
  * {@link Authorizer}, and {@link SessionManager} interfaces, thereby consolidating
  * these behaviors into a single point of reference.  For most Ki usages, this simplifies configuration and
  * tends to be a more convenient approach than referencing <code>Authenticator</code>, <code>Authorizer</code>, and
  * <code>SessionManager</code> instances seperately;  instead one only needs to interact with a
  * single <tt>SecurityManager</tt> instance.
  * <p/>
  * In addition to the above three interfaces, three unique methods are provided by this interface by itself,
  * {@link #login}, {@link #logout} and {@link #getSubject}.  A {@link org.apache.ki.subject.Subject Subject} executes
  * authentication, authorization, and session operations for a <em>single</em> user, and as such can only be
  * managed by <tt>A SecurityManager</tt> which is aware of all three functions.  The three parent interfaces on the
  * other hand do not 'know' about <tt>Subject</tt>s to ensure a clean separation of concerns.
@@ -50,14 +50,14 @@
  * <p/>
  * In that case, the application programmer can call the
  * {@link #getSubject() getSubject()} method and then use that returned instance for continued interaction with
  * Ki.  If your application code does not have a direct handle to the application's
  * <code>SecurityManager</code>, you can use {@link org.apache.ki.SecurityUtils SecurityUtils} anywhere in your code
  * to achieve the same result.
  * <p/>
  * Framework developers on the other hand might find working with an actual SecurityManager useful.
  *
  * @author Les Hazlewood
- * @see org.apache.ki.mgt.DefaultSecurityManager
+ * @see org.apache.shiro.mgt.DefaultSecurityManager
  * @since 0.2
  */
 public interface SecurityManager extends Authenticator, Authorizer, SessionManager {
@@ -68,14 +68,14 @@
      * <p/>
      * Note that most application developers should probably not call this method directly unless they have a good
      * reason for doing so.  The preferred way to log in a Subject is to call
      * <code>subject.{@link org.apache.ki.subject.Subject#login login(authenticationToken)}</code> (usually after
      * acquiring the Subject by calling {@link org.apache.ki.SecurityUtils#getSubject() SecurityUtils.getSubject()}).
      * <p/>
      * Framework developers on the other hand might find calling this method directly useful in certain cases.
      *
      * @param authenticationToken the token representing the Subject's principal(s) and credential(s)
      * @return an authenticated Subject upon a successful attempt
-     * @throws org.apache.ki.authc.AuthenticationException
+     * @throws org.apache.shiro.authc.AuthenticationException
      *          if the login attempt failed.
      * @since 0.9
      */
@@ -86,7 +86,7 @@
      * <p/>
      * Note that most application developers should not call this method unless they have a good reason for doing
      * so.  The preferred way to logout a Subject is to call
      * <code>{@link org.apache.ki.subject.Subject#logout Subject.logout()}</code>, not the
      * <code>SecurityManager</code> directly.
      * <p/>
      * Framework developers on the other hand might find calling this method directly useful in certain cases.
@@ -16,30 +16,30 @@
  * single application.
  * <p/>
- * The interface itself primarily exists as a convenience - it extends the {@link org.apache.ki.authc.Authenticator},
+ * The interface itself primarily exists as a convenience - it extends the {@link org.apache.shiro.authc.Authenticator},
  * {@link Authorizer}, and {@link SessionManager} interfaces, thereby consolidating
@@ -16,30 +16,30 @@
  * {@link Authorizer}, and {@link SessionManager} interfaces, thereby consolidating
- * these behaviors into a single point of reference.  For most Ki usages, this simplifies configuration and
+ * these behaviors into a single point of reference.  For most Shiro usages, this simplifies configuration and
  * tends to be a more convenient approach than referencing <code>Authenticator</code>, <code>Authorizer</code>, and
  * <code>SessionManager</code> instances seperately;  instead one only needs to interact with a
@@ -16,30 +16,30 @@
  * <p/>
  * In addition to the above three interfaces, three unique methods are provided by this interface by itself,
- * {@link #login}, {@link #logout} and {@link #getSubject}.  A {@link org.apache.ki.subject.Subject Subject} executes
+ * {@link #login}, {@link #logout} and {@link #getSubject}.  A {@link org.apache.shiro.subject.Subject Subject} executes
  * authentication, authorization, and session operations for a <em>single</em> user, and as such can only be
  * managed by <tt>A SecurityManager</tt> which is aware of all three functions.  The three parent interfaces on the
@@ -50,14 +50,14 @@
  * In that case, the application programmer can call the
  * {@link #getSubject() getSubject()} method and then use that returned instance for continued interaction with
- * Ki.  If your application code does not have a direct handle to the application's
- * <code>SecurityManager</code>, you can use {@link org.apache.ki.SecurityUtils SecurityUtils} anywhere in your code
+ * Shiro.  If your application code does not have a direct handle to the application's
+ * <code>SecurityManager</code>, you can use {@link org.apache.shiro.SecurityUtils SecurityUtils} anywhere in your code
  * to achieve the same result.
  * <p/>
@@ -68,14 +68,14 @@
      * Note that most application developers should probably not call this method directly unless they have a good
      * reason for doing so.  The preferred way to log in a Subject is to call
-     * <code>subject.{@link org.apache.ki.subject.Subject#login login(authenticationToken)}</code> (usually after
-     * acquiring the Subject by calling {@link org.apache.ki.SecurityUtils#getSubject() SecurityUtils.getSubject()}).
+     * <code>subject.{@link org.apache.shiro.subject.Subject#login login(authenticationToken)}</code> (usually after
+     * acquiring the Subject by calling {@link org.apache.shiro.SecurityUtils#getSubject() SecurityUtils.getSubject()}).
      * <p/>
      * Framework developers on the other hand might find calling this method directly useful in certain cases.
@@ -86,7 +86,7 @@
      * Note that most application developers should not call this method unless they have a good reason for doing
      * so.  The preferred way to logout a Subject is to call
-     * <code>{@link org.apache.ki.subject.Subject#logout Subject.logout()}</code>, not the
+     * <code>{@link org.apache.shiro.subject.Subject#logout Subject.logout()}</code>, not the
      * <code>SecurityManager</code> directly.
      * <p/>

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SecurityManagerAware.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SecurityManagerAware.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SecurityManagerAware.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SecurityManagerAware.java Thu Jun 18 03:13:34 2009
@@ -16,12 +16,12 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
 /**
  * Interface providing a callback method that allows an implementation of this interface to receive a reference to
  * the {@link org.apache.ki.mgt.SecurityManager SecurityManager} if they require one.  This is mostly used by core implementation classes
  * for framework code and is rarely necessary for software developers enabling Ki in their applications.
  *
  * @author Les Hazlewood
  * @since 1.0
@@ -29,10 +29,10 @@
 public interface SecurityManagerAware {
 
     /**
      * Callback method that allows a component to receive the {@link org.apache.ki.mgt.SecurityManager SecurityManager} instance if it
      * requires one.
      *
      * @param securityManager the application's <code>SecurityManager</code>
      */
-    void setSecurityManager(org.apache.ki.mgt.SecurityManager securityManager);
+    void setSecurityManager(org.apache.shiro.mgt.SecurityManager securityManager);
 }
@@ -16,12 +16,12 @@
 /**
  * Interface providing a callback method that allows an implementation of this interface to receive a reference to
- * the {@link org.apache.ki.mgt.SecurityManager SecurityManager} if they require one.  This is mostly used by core implementation classes
- * for framework code and is rarely necessary for software developers enabling Ki in their applications.
+ * the {@link org.apache.shiro.mgt.SecurityManager SecurityManager} if they require one.  This is mostly used by core implementation classes
+ * for framework code and is rarely necessary for software developers enabling Shiro in their applications.
  *
  * @author Les Hazlewood
@@ -29,10 +29,10 @@
 
     /**
-     * Callback method that allows a component to receive the {@link org.apache.ki.mgt.SecurityManager SecurityManager} instance if it
+     * Callback method that allows a component to receive the {@link org.apache.shiro.mgt.SecurityManager SecurityManager} instance if it
      * requires one.
      *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SecurityManagerFactory.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SecurityManagerFactory.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SessionSubjectBinder.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SessionSubjectBinder.java Thu Jun 18 03:13:34 2009
@@ -16,16 +16,16 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
-import org.apache.ki.session.Session;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.subject.Subject;
 
 
 /**
  * Binds the Subject's state to the accessible {@link Session Session} in addition to the
- * {@link org.apache.ki.util.ThreadContext ThreadContext}
+ * {@link org.apache.shiro.util.ThreadContext ThreadContext}
  * <p/>
  * The very notion of this class's existence might sound backwards:  typically a {@link Session Session} is something
  * that is created <em>after</em> a {@link Subject Subject} is acquired - for example by calling
@@ -43,7 +43,7 @@
  * <ol>
  * <li>A session ID would be acquired based on an incoming request or remote method invocation</li>
  * <li>The <code>Session</code> would be retrieved from the application's {@link SecurityManager SecurityManager}
  * (using the {@link org.apache.ki.session.mgt.SessionManager SessionManager} parent methods)</li>
  * <li>A <code>Subject</code> instance would be created based on the attributes found in that session</code>
  * <li>The constructed <code>Subject</code> would be 'bound' to the application for use during the request or method
  * invocation (say, bound to the processing thread)</li>
@@ -54,7 +54,7 @@
  * end of request/thread execution, and a new one is created on the next request/method invocation as per step #1.</li>
  * </ol>
  * <p/>
  * Indeed this is exactly how Ki's default behavior works in enterprise server and web-based environments.  It is
  * enabled in the <code>KiFilter</code> for web-based environments as well as remote-method-invocation-based
  * components for non-web environments.
  *
@@ -43,7 +43,7 @@
  * <li>A session ID would be acquired based on an incoming request or remote method invocation</li>
  * <li>The <code>Session</code> would be retrieved from the application's {@link SecurityManager SecurityManager}
- * (using the {@link org.apache.ki.session.mgt.SessionManager SessionManager} parent methods)</li>
+ * (using the {@link org.apache.shiro.session.mgt.SessionManager SessionManager} parent methods)</li>
  * <li>A <code>Subject</code> instance would be created based on the attributes found in that session</code>
  * <li>The constructed <code>Subject</code> would be 'bound' to the application for use during the request or method
@@ -54,7 +54,7 @@
  * </ol>
  * <p/>
- * Indeed this is exactly how Ki's default behavior works in enterprise server and web-based environments.  It is
+ * Indeed this is exactly how Shiro's default behavior works in enterprise server and web-based environments.  It is
  * enabled in the <code>KiFilter</code> for web-based environments as well as remote-method-invocation-based
  * components for non-web environments.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SessionsSecurityManager.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SessionsSecurityManager.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SessionsSecurityManager.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SessionsSecurityManager.java Thu Jun 18 03:13:34 2009
@@ -16,18 +16,18 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
-import org.apache.ki.authz.AuthorizationException;
-import org.apache.ki.cache.CacheManagerAware;
-import org.apache.ki.session.InvalidSessionException;
-import org.apache.ki.session.Session;
-import org.apache.ki.session.SessionListener;
-import org.apache.ki.session.SessionListenerRegistrar;
-import org.apache.ki.session.mgt.*;
-import org.apache.ki.session.mgt.eis.SessionDAO;
-import org.apache.ki.session.mgt.eis.SessionDAOAware;
-import org.apache.ki.util.LifecycleUtils;
+import org.apache.shiro.authz.AuthorizationException;
+import org.apache.shiro.cache.CacheManagerAware;
+import org.apache.shiro.session.InvalidSessionException;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.session.SessionListener;
+import org.apache.shiro.session.SessionListenerRegistrar;
+import org.apache.shiro.session.mgt.*;
+import org.apache.shiro.session.mgt.eis.SessionDAO;
+import org.apache.shiro.session.mgt.eis.SessionDAOAware;
+import org.apache.shiro.util.LifecycleUtils;
 
 import java.io.Serializable;
 import java.net.InetAddress;
@@ -37,8 +37,8 @@
 
 
 /**
  * Ki support of a {@link SecurityManager} class hierarchy that delegates all
  * {@link org.apache.ki.session.Session session} operations to a wrapped {@link org.apache.ki.session.mgt.SessionManager SessionManager}
  * instance.  That is, this class implements the methods in the
  * {@link SessionManager SessionManager} interface, but in reality, those methods are merely passthrough calls to
  * the underlying 'real' {@code SessionManager} instance.
@@ -46,7 +46,7 @@
  * The remaining {@code SecurityManager} methods not implemented by this class or its parents are left to be
  * implemented by subclasses.
  * <p/>
  * In keeping with the other classes in this hierarchy and Ki's desire to minimize configuration whenever
  * possible, suitable default instances for all dependencies will be created upon instantiation.
  *
  * @author Les Hazlewood
@@ -97,14 +97,14 @@
      * Returns this security manager's internal delegate {@link SessionManager SessionManager}.
      *
      * @return this security manager's internal delegate {@link SessionManager SessionManager}.
-     * @see #setSessionManager(org.apache.ki.session.mgt.SessionManager) setSessionManager
+     * @see #setSessionManager(org.apache.shiro.session.mgt.SessionManager) setSessionManager
      */
     public SessionManager getSessionManager() {
         return this.sessionManager;
     }
 
     /**
      * Calls {@link org.apache.ki.mgt.AuthorizingSecurityManager#afterCacheManagerSet() super.afterCacheManagerSet()} and then immediately calls
      * {@link #applyCacheManagerToSessionManager() applyCacheManagerToSessionManager()} to ensure the
      * <code>CacheManager</code> is applied to the SessionManager as necessary.
      */
@@ -188,8 +188,8 @@
                     "The current SessionManager is of type [" + this.sessionManager.getClass().getName() + "].  " +
                     "This might occur for example if you're trying to set the validation interval or auto session " +
                     "creation in a servlet container-backed session environment ('http' session mode).  If that is " +
-                    "the case however, that property is only useful when using 'ki' session mode and using " +
-                    "Ki enterprise sessions which do not rely on a servlet container.";
+                    "the case however, that property is only useful when using 'shiro' session mode and using " +
+                    "Shiro enterprise sessions which do not rely on a servlet container.";
             throw new IllegalStateException(msg);
         }
     }
@@ -197,13 +197,13 @@
     /**
      * Passthrough configuration property to the underlying {@link AbstractSessionManager AbstractSessionManager}
      * instance.  Please read the
-     * {@link org.apache.ki.session.mgt.AbstractSessionManager#getGlobalSessionTimeout() AbstractSessionManager.getGlobalSessionTimeout()}
+     * {@link org.apache.shiro.session.mgt.AbstractSessionManager#getGlobalSessionTimeout() AbstractSessionManager.getGlobalSessionTimeout()}
      * for more.
      *
      * @return the time in milliseconds that any {@link Session Session} may remain idle before expiring.
      * @throws IllegalStateException if the underlying {@code SessionManager} instance is not a subclass of
      *                               {@link AbstractSessionManager AbstractSessionManager}.
-     * @see org.apache.ki.session.mgt.AbstractSessionManager#getGlobalSessionTimeout()
+     * @see org.apache.shiro.session.mgt.AbstractSessionManager#getGlobalSessionTimeout()
      */
     public long getGlobalSessionTimeout() {
         assertSessionManager(AbstractSessionManager.class);
@@ -213,13 +213,13 @@
     /**
      * Passthrough configuration property to the underlying {@link AbstractSessionManager AbstractSessionManager}
      * instance.  Please read the
-     * {@link org.apache.ki.session.mgt.AbstractSessionManager#setGlobalSessionTimeout(long) AbstractSessionManager.setGlobalSessionTimeout(long)}
+     * {@link org.apache.shiro.session.mgt.AbstractSessionManager#setGlobalSessionTimeout(long) AbstractSessionManager.setGlobalSessionTimeout(long)}
      * for more.
      *
      * @param globalSessionTimeout the time in milliseconds that any {@link Session Session} may remain idle before expiring.
      * @throws IllegalStateException if the underlying {@code SessionManager} instance is not a subclass of
-     *                               {@link org.apache.ki.session.mgt.AbstractSessionManager AbstractSessionManager}.
-     * @see org.apache.ki.session.mgt.AbstractSessionManager#setGlobalSessionTimeout(long)
+     *                               {@link org.apache.shiro.session.mgt.AbstractSessionManager AbstractSessionManager}.
+     * @see org.apache.shiro.session.mgt.AbstractSessionManager#setGlobalSessionTimeout(long)
      */
     public void setGlobalSessionTimeout(long globalSessionTimeout) {
         assertSessionManager(AbstractSessionManager.class);
@@ -227,19 +227,19 @@
     }
 
     /**
      * Passthrough configuration property to the wrapped {@link org.apache.ki.session.mgt.AbstractValidatingSessionManager} - if it should
      * automatically create a new session when an invalid session is referenced.  The default value unless
      * overridden by this method is <code>true</code> for developer convenience and to match what most people are
      * accustomed based on years of servlet container behavior.
      * <p/>
      * When true (the default), the wrapped {@link AbstractValidatingSessionManager} implementation throws an
      * {@link org.apache.ki.session.ReplacedSessionException ReplacedSessionException} to the caller whenever a new
      * session is created so the caller can receive the new session ID and react accordingly for future
      * {@link SessionManager SessionManager} method invocations.
      *
      * @param autoCreate if the wrapped {@link AbstractValidatingSessionManager} should automatically create a new
      *                   session when an invalid session is referenced
-     * @see org.apache.ki.session.mgt.AbstractValidatingSessionManager#setAutoCreateWhenInvalid(boolean)
+     * @see org.apache.shiro.session.mgt.AbstractValidatingSessionManager#setAutoCreateWhenInvalid(boolean)
      */
     public void setAutoCreateSessionAfterInvalidation(boolean autoCreate) {
         assertSessionManager(AbstractValidatingSessionManager.class);
@@ -248,19 +248,19 @@
 
     /**
      * Passthrough configuration property that returns <code>true</code> if the wrapped
      * {@link org.apache.ki.session.mgt.AbstractValidatingSessionManager AbstractValidatingSessionManager} should automatically create a
      * new session when an invalid session is referenced, <code>false</code> otherwise.  Unless overridden by the
      * {@link #setAutoCreateSessionAfterInvalidation(boolean)} method, the default value is <code>true</code> for
      * developer convenience and to match what most people are accustomed based on years of servlet container behavior.
      * <p/>
      * When true (the default), the wrapped {@link org.apache.ki.session.mgt.AbstractValidatingSessionManager AbstractValidatingSessionManager}
      * implementation throws an {@link org.apache.ki.session.ReplacedSessionException ReplacedSessionException} to
      * the caller whenever a new session is created so the caller can receive the new session ID and react accordingly
      * for future {@link SessionManager SessionManager} method invocations.
      *
      * @return <code>true</code> if this session manager should automatically create a new session when an invalid
      *         session is referenced, <code>false</code> otherwise.
-     * @see org.apache.ki.session.mgt.AbstractValidatingSessionManager#isAutoCreateWhenInvalid()
+     * @see org.apache.shiro.session.mgt.AbstractValidatingSessionManager#isAutoCreateWhenInvalid()
      */
     public boolean isAutoCreateSessionAfterInvalidation() {
         assertSessionManager(AbstractValidatingSessionManager.class);
@@ -269,7 +269,7 @@
 
     /**
      * Ensures the internal SessionManager instance is an <code>instanceof</code>
      * {@link org.apache.ki.session.SessionListenerRegistrar SessionListenerRegistrar} to ensure that any
      * listeners attempting to be registered can actually do so with the internal delegate instance.
      *
      * @throws IllegalStateException if the internal delegate SessionManager instance does not implement the
@@ -300,7 +300,7 @@
 
     /**
      * Removes the specified listener from receiving session events from the internal delegate
-     * {@link org.apache.ki.session.mgt.SessionManager} instance.
+     * {@link org.apache.shiro.session.mgt.SessionManager} instance.
      *
      * @param listener the listener to remove that no longer wishes to be notified of session events.
      * @return <code>true</code> if the listener was removed from the internal delegate <code>SessionManager</code>
@@ -37,8 +37,8 @@
 
 /**
- * Ki support of a {@link SecurityManager} class hierarchy that delegates all
- * {@link org.apache.ki.session.Session session} operations to a wrapped {@link org.apache.ki.session.mgt.SessionManager SessionManager}
+ * Shiro support of a {@link SecurityManager} class hierarchy that delegates all
+ * {@link org.apache.shiro.session.Session session} operations to a wrapped {@link org.apache.shiro.session.mgt.SessionManager SessionManager}
  * instance.  That is, this class implements the methods in the
  * {@link SessionManager SessionManager} interface, but in reality, those methods are merely passthrough calls to
@@ -46,7 +46,7 @@
  * implemented by subclasses.
  * <p/>
- * In keeping with the other classes in this hierarchy and Ki's desire to minimize configuration whenever
+ * In keeping with the other classes in this hierarchy and Shiro's desire to minimize configuration whenever
  * possible, suitable default instances for all dependencies will be created upon instantiation.
  *
@@ -97,14 +97,14 @@
 
     /**
-     * Calls {@link org.apache.ki.mgt.AuthorizingSecurityManager#afterCacheManagerSet() super.afterCacheManagerSet()} and then immediately calls
+     * Calls {@link org.apache.shiro.mgt.AuthorizingSecurityManager#afterCacheManagerSet() super.afterCacheManagerSet()} and then immediately calls
      * {@link #applyCacheManagerToSessionManager() applyCacheManagerToSessionManager()} to ensure the
      * <code>CacheManager</code> is applied to the SessionManager as necessary.
@@ -227,19 +227,19 @@
 
     /**
-     * Passthrough configuration property to the wrapped {@link org.apache.ki.session.mgt.AbstractValidatingSessionManager} - if it should
+     * Passthrough configuration property to the wrapped {@link org.apache.shiro.session.mgt.AbstractValidatingSessionManager} - if it should
      * automatically create a new session when an invalid session is referenced.  The default value unless
      * overridden by this method is <code>true</code> for developer convenience and to match what most people are
@@ -227,19 +227,19 @@
      * <p/>
      * When true (the default), the wrapped {@link AbstractValidatingSessionManager} implementation throws an
-     * {@link org.apache.ki.session.ReplacedSessionException ReplacedSessionException} to the caller whenever a new
+     * {@link org.apache.shiro.session.ReplacedSessionException ReplacedSessionException} to the caller whenever a new
      * session is created so the caller can receive the new session ID and react accordingly for future
      * {@link SessionManager SessionManager} method invocations.
@@ -248,19 +248,19 @@
     /**
      * Passthrough configuration property that returns <code>true</code> if the wrapped
-     * {@link org.apache.ki.session.mgt.AbstractValidatingSessionManager AbstractValidatingSessionManager} should automatically create a
+     * {@link org.apache.shiro.session.mgt.AbstractValidatingSessionManager AbstractValidatingSessionManager} should automatically create a
      * new session when an invalid session is referenced, <code>false</code> otherwise.  Unless overridden by the
      * {@link #setAutoCreateSessionAfterInvalidation(boolean)} method, the default value is <code>true</code> for
@@ -248,19 +248,19 @@
      * developer convenience and to match what most people are accustomed based on years of servlet container behavior.
      * <p/>
-     * When true (the default), the wrapped {@link org.apache.ki.session.mgt.AbstractValidatingSessionManager AbstractValidatingSessionManager}
-     * implementation throws an {@link org.apache.ki.session.ReplacedSessionException ReplacedSessionException} to
+     * When true (the default), the wrapped {@link org.apache.shiro.session.mgt.AbstractValidatingSessionManager AbstractValidatingSessionManager}
+     * implementation throws an {@link org.apache.shiro.session.ReplacedSessionException ReplacedSessionException} to
      * the caller whenever a new session is created so the caller can receive the new session ID and react accordingly
      * for future {@link SessionManager SessionManager} method invocations.
@@ -269,7 +269,7 @@
     /**
      * Ensures the internal SessionManager instance is an <code>instanceof</code>
-     * {@link org.apache.ki.session.SessionListenerRegistrar SessionListenerRegistrar} to ensure that any
+     * {@link org.apache.shiro.session.SessionListenerRegistrar SessionListenerRegistrar} to ensure that any
      * listeners attempting to be registered can actually do so with the internal delegate instance.
      *

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SubjectBinder.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SubjectBinder.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SubjectFactory.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/SubjectFactory.java Thu Jun 18 03:13:34 2009
@@ -16,13 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
 
-import org.apache.ki.authc.AuthenticationInfo;
-import org.apache.ki.authc.AuthenticationToken;
-import org.apache.ki.session.Session;
-import org.apache.ki.subject.PrincipalCollection;
-import org.apache.ki.subject.Subject;
+import org.apache.shiro.authc.AuthenticationInfo;
+import org.apache.shiro.authc.AuthenticationToken;
+import org.apache.shiro.session.Session;
+import org.apache.shiro.subject.PrincipalCollection;
+import org.apache.shiro.subject.Subject;
 
 import java.net.InetAddress;
 
@@ -57,7 +57,7 @@
      * @param principals      the identifying attributes of the Subject instance to be created, or
      *                        {@code null} if the Subject's identity is unknown because they haven't logged in yet and are not 'remembered'
      *                        from {@code RememberMe} services.
      * @param existing        any {@link org.apache.ki.session.Session Session} that might be in place for the specified {@link org.apache.ki.subject.Subject}, or
      *                        {@code null} if there is no session yet created for the specified {@code Subject}.  If non-{@code null},
      *                        it should be retained and used by the {@code Subject} instance returned from this method call.
      * @param authenticated   whether or not the {@code Subject} instance returned should be considered already
@@ -57,7 +57,7 @@
      *                        {@code null} if the Subject's identity is unknown because they haven't logged in yet and are not 'remembered'
      *                        from {@code RememberMe} services.
-     * @param existing        any {@link org.apache.ki.session.Session Session} that might be in place for the specified {@link org.apache.ki.subject.Subject}, or
+     * @param existing        any {@link org.apache.shiro.session.Session Session} that might be in place for the specified {@link org.apache.shiro.subject.Subject}, or
      *                        {@code null} if there is no session yet created for the specified {@code Subject}.  If non-{@code null},
      *                        it should be retained and used by the {@code Subject} instance returned from this method call.

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/ThreadContextSubjectBinder.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/ThreadContextSubjectBinder.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/mgt/package-info.java Thu Jun 18 03:13:34 2009
@@ -17,7 +17,7 @@
  * under the License.
  */
 /**
  * Provides the master {@link org.apache.ki.mgt.SecurityManager SecurityManager} interface and a default implementation
  * hierarchy for managing all aspects of Ki's functionality in an application.
  */
-package org.apache.ki.mgt;
+package org.apache.shiro.mgt;
@@ -17,7 +17,7 @@
  */
 /**
- * Provides the master {@link org.apache.ki.mgt.SecurityManager SecurityManager} interface and a default implementation
- * hierarchy for managing all aspects of Ki's functionality in an application.
+ * Provides the master {@link org.apache.shiro.mgt.SecurityManager SecurityManager} interface and a default implementation
+ * hierarchy for managing all aspects of Shiro's functionality in an application.
  */

Modified: incubator/shiro/trunk/core/src/main/java/org/apache/shiro/package-info.java
URL: http://svn.apache.org/viewvc/incubator/shiro/trunk/core/src/main/java/org/apache/shiro/package-info.java?rev=785881&r1=785781&r2=785881&view=diff
==============================================================================
--- incubator/shiro/trunk/core/src/main/java/org/apache/shiro/package-info.java (original)
+++ incubator/shiro/trunk/core/src/main/java/org/apache/shiro/package-info.java Thu Jun 18 03:13:34 2009
@@ -18,7 +18,7 @@
  */
 /**
  * This package primarily exists as a root classpath distinction, but it does contain two core classes widely used
  * by applications, {@link org.apache.ki.SecurityUtils SecurityUtils} and
  * {@link org.apache.ki.KiException KiException}.
  */
-package org.ki;
+package org.shiro;
@@ -18,7 +18,7 @@
 /**
  * This package primarily exists as a root classpath distinction, but it does contain two core classes widely used
- * by applications, {@link org.apache.ki.SecurityUtils SecurityUtils} and
- * {@link org.apache.ki.KiException KiException}.
+ * by applications, {@link org.apache.shiro.SecurityUtils SecurityUtils} and
+ * {@link org.apache.shiro.ShiroException KiException}.
  */